package cn.com.qmth.examcloud.core.print.api.controller;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import cn.com.qmth.examcloud.commons.web.support.ControllerSupport;
import cn.com.qmth.examcloud.core.print.common.Result;
import cn.com.qmth.examcloud.core.print.service.ExamStructureService;
import cn.com.qmth.examcloud.core.print.service.bean.ExamStructureInfo;
import cn.com.qmth.examcloud.core.print.service.bean.ExamStructureQuery;

/**
 * 导出结构设置信息相关接口（前端）
 * 
 * @author weiwenhai
 * @since  2018.10.31
 */
@RestController
@Api(tags = "导出结构设置信息相关接口")
@RequestMapping("${$rmp.ctrl.print}/examStructure")
public class ExamStructureController extends ControllerSupport{

	@Autowired
	private ExamStructureService examStructureService;
	
	@PostMapping("/list")
	@ApiOperation(value = "查询导出结构设置信息（分页）")
	public Page<ExamStructureInfo> getExamStructureList(@RequestBody ExamStructureQuery query){
		Page<ExamStructureInfo> list = examStructureService.getExamStructureList(query);
		return list;
	}
	
	@PostMapping("/findOne")
	@ApiOperation(value = "根据机构id和考试id查询")
	public ExamStructureInfo getExamStructure(@RequestBody ExamStructureQuery query){
		ExamStructureInfo info = examStructureService.getExamStructure(query);
		return info;
	}
	
	@SuppressWarnings("rawtypes")
	@PostMapping("/save")
	@ApiOperation(value = "保存导出结构设置信息")
	public Result saveExamStructure(@RequestBody ExamStructureInfo info){
		examStructureService.saveExamStructure(info);
		return Result.success();
	}
	
	@SuppressWarnings("rawtypes")
	@DeleteMapping("/delete/{ids}")
	@ApiOperation(value = "删除导出结构设置信息")
	public Result deleteExamStructure(@PathVariable String ids){
		List<Long> list = Arrays.asList(ids.split(",")).stream().map(s -> Long.parseLong(s.trim())).collect(Collectors.toList());
		examStructureService.deleteExamStructure(list);
		return Result.success();
	}
	
	@SuppressWarnings("rawtypes")
	@PostMapping("/copy")
	@ApiOperation(value = "复制导出结构设置信息")
	public Result copyExamStructure(@RequestBody ExamStructureInfo info){
		examStructureService.copyExamStructure(info);
		return Result.success();
	}
}
